@@ -1,8 +1,17 @@
 #!python
 
+try:
+    from .ms_data_base import ms_reader_provider
+    from .sciex import SciexWiffData
+    from .thermo import ThermoRawData
+    from .legacy_msdata import mgf
+    from .legacy_msdata import mzml
+    from .wrappers import alphapept_wrapper
+except ImportError:
+    pass
 
 __project__ = "alpharaw"
-__version__ = "0.0.2"
+__version__ = "0.1.0"
 __license__ = "Apache"
 __description__ = "An open-source Python package to unify raw MS data accession and storage."
 __author__ = "Mann Labs"
@@ -17,7 +26,7 @@ __keywords__ = [
     "data accession",
     "data storage"
 ]
-__python_version__ = ">=3.8,<3.10"
+__python_version__ = ">=3.8"
 __classifiers__ = [
     # "Development Status :: 1 - Planning",
     "Development Status :: 2 - Pre-Alpha",
